<?php
/*
 * This file is part of Sylar.
 *
 * Sylar is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sylar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Sylar.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @copyright Copyright Sylar Development Team
 * @license http://www.gnu.org/licenses/ GNU Public License V2.0
 * @see https://launchpad.net/sylar/
 * @see http://www.giano-solutions.com
 */

/**
 * Configuration Box
 * 
 * A class that conteins all Sylar Configuration values read from config and settings file.
 * 
 * @package Sylar
 * @version 1.0
 * @since 16/feb/08
 * @author Gianluca Giusti [brdp] <g.giusti@giano-solutions.com>
 * @copyright Sylar Development Team 
 */ 
class Sylar_ConfigBox{
	
	function __construct(){
		# nothing to do
	}
	function __destruct() {
		# nothing to do
	}

	/**
	 * Db type name
	 * returns the name of db used, like mysql, oracle, ecc... The code must 
	 * be one of directory in the db package, for example: 
	 * db.mysql.MysqlDriver	=>	name is "mysql"
	 * db.oracle.OracleDriver	=> 	name is "oracle"
	 * 
	 * The name is also used tu include the class file
	 * 
	 * @since 16/feb/08
 	 * @author Gianluca Giusti [brdp] <g.giusti@giano-solutions.com>
	 * 
	 * @see SYLAR_USED_DB
	 * 
	 * @return string The code of DbTyle like mysql, oracle
	 */
	public static function getDbType($dbUsed=SYLAR_USED_DB){
		global $SYLAR_DB;
		return $SYLAR_DB[$dbUsed]['type'];
	}
	
	/**
	 * Level of logger
	 * 
	 * @since 16/feb/08
 	 * @author Gianluca Giusti [brdp] <g.giusti@giano-solutions.com>
 	 *
	 * @return string
	 */
	public static function getLogLevel(){
		return SYLAR_LOG_LEVEL;
	}
	
	/**
	 * Debugmode
	 * Return true if Sylar is in debug mode, false otherwise
	 * 
	 * @since 16/feb/08
 	 * @author Gianluca Giusti [brdp] <g.giusti@giano-solutions.com>
	 * 
	 * @return boolean
	 * 
	 * @see SYLAR_DEBUG_MODE
	 */
	public static function isSylarInDebugMode(){
		if(SYLAR_DEBUG_MODE){
			return true;
		}else{
			return false;
		}
	}
	
	/**
	 * Chek if a session is enable and required.
	 * return true if a session is ON, false otherwise.
	 * 
	 * @since 16/feb/08
 	 * @author Gianluca Giusti [brdp] <g.giusti@giano-solutions.com>
 	 *
	 * @return boolean
	 */
	public static function isSessionEnabled(){
		if(SYLAR_SESSION_NAME){
			return true;
		}else{
			return false;
		}
	}

	/**
	 * return the name of the PHP session
	 * 
	 * @since 16/feb/08
 	 * @author Gianluca Giusti [brdp] <g.giusti@giano-solutions.com>
 	 *
	 * @return string
	 */
	public static function getSessionName(){
		return SYLAR_SESSION_NAME;
	}
	
	/**
	 * return an array with all avaiable defined databases
	 * @see $SYLAR_DB
	 * @see sylar.php
	 * 
	 * @since 16/feb/08
 	 * @author Gianluca Giusti [brdp] <g.giusti@giano-solutions.com>
 	 *
	 * @return array
	 */
	public static function provideAvaiableDbList(){
		global $SYLAR_DB;
		return $SYLAR_DB;
	}
	
}
 
 
 
?>